Crate nstreams_core

Crate nstreams_core 

Generic versioned event stream handler with history replay.

Events are namespaced: the namespace determines queue/stream names, backend storage, and the shape of the event payload.

Re-exports

pub use error::Error;
pub use error::Result;
pub use event::DeliveredEvent;
pub use event::EventCodec;
pub use event::StreamEvent;
pub use event::StreamEventEnvelope;
pub use filter::StreamFilter;
pub use filter::SubscribeRequest;
pub use request_id::new_request_id;
pub use request_id::REQUEST_ID_PREFIX;
pub use handler::NStreamsHandler;
pub use namespace::Namespace;
pub use publisher::EventPublisher;
pub use store::EventStore;
pub use stream::ReadStreamBackend;
pub use stream::WriteQueueBackend;
pub use subscription::Subscription;
pub use version::VersionedDelivery;
pub use worker::StreamWorker;

Modules

error
event
filter
Stream subscription filters for RabbitMQ Bloom filtering.
handler
namespace
publisher
request_id
store
stream
subscription
version
worker

Constants

DEFAULT_MAX_EVENT_BYTES
Default assumed maximum serialized event size in bytes when sizing streams.
MAX_STREAM_HISTORY_ITEMS
Maximum history items retained in a read stream.
STREAM_MAX_AGE
RabbitMQ stream max-age for read streams (six months).

Functions

stream_max_length_bytes
Compute the byte capacity for a read stream given an estimated event size.