Module namespace

Module namespace 

Structs

NamespaceResources
Resolve resource names for a typed namespace.
StreamNamespace
String-backed namespace identifier.

Traits

Namespace
Identifies an event namespace.

Functions

postgres_table_name
PostgreSQL table name for a namespace’s persisted events.
read_stream_name
RabbitMQ stream name for the read path of a namespace.
write_queue_name
RabbitMQ queue name for the write path of a namespace.